#include <set>
#include <iostream>
#include <vector>

using namespace std;

long long N;

struct Segment {
    long long left;
    long long right;

    long long max_dist() {
        if (right == N || left == 1) {
            return right - left;
        }
        return (right - left) / 2;
    }
};

auto cmp_by_len = [](Segment a, Segment b) {
    if (a.max_dist() == b.max_dist()) {
        return a.right > b.right;
    }
    return a.max_dist() < b.max_dist();
};
auto cmp_by_left = [](Segment a, Segment b) {
    return a.left < b.left;
};

set<Segment, decltype(cmp_by_len)> set_by_len(cmp_by_len);
set<Segment, decltype(cmp_by_left)> set_by_left(cmp_by_left);

void add(Segment &x) {
    if (x.left <= x.right) {
        set_by_len.insert(x);
        set_by_left.insert(x);
    }
}

void erase(Segment &x) {
    set_by_len.erase(x);
    set_by_left.erase(x);
}

int main() {
    cin >> N;
    int K;
    cin >> K;

    Segment empty{1, N};
    add(empty);

    std::vector<long long> ans;

    for (size_t i = 0; i < K; i++) {
        char a;
        cin >> a;
        if (a == '+') {
            auto seg = *std::prev(set_by_len.end());
            erase(seg);
            if (seg.left == 1) {
                ans.push_back(1);
                seg.left++;
                add(seg);
            } else if (seg.right == N) {
                ans.push_back(N);
                seg.right--;
                add(seg);
            } else {
                long long pos = seg.left + (seg.right - seg.left) / 2;
                Segment seg1{seg.left, pos - 1};
                Segment seg2{pos + 1, seg.right};
                ans.push_back(pos);
                add(seg1);
                add(seg2);
            }
        } else if (a == '-') {
            int x;
            cin >> x;
            long long y = ans[x - 1];
            Segment seg{y, y};
            Segment left{0, 0};
            Segment right{0, 0};

            if (auto r = set_by_left.upper_bound(seg); r != set_by_left.end()) {
                if (r->left - 1 == y) {
                    right = *r;
                }
            }

            if (auto l = set_by_left.upper_bound(seg); l != set_by_left.begin()) {
                l--;
                if (l->right + 1 == y) {
                    left = *l;
                }
            }

            if (!left.left && !right.left) {
                add(seg);
            } else if (left.left && right.right) {
                Segment big_seg{left.left, right.right};
                erase(left);
                erase(right);
                add(big_seg);
            } else if (left.left) {
                erase(left);
                left.right++;
                add(left);
            } else if (right.left) {
                erase(right);
                right.left--;
                add(right);
            }
        }
    }

    for (auto a : ans) {
        cout << a << endl;
    }
}
